<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
<context>
    <name>IconThemeConfig</name>
    <message>
        <source>Razor Appearance Configuration</source>
        <translation>Razor Indstillinger for Udseende</translation>
    </message>
    <message>
        <source>Icons Theme</source>
        <translation>Ikontema</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Razor Appearance Configuration</source>
        <translation>Razor Indstillinger for Udseende</translation>
    </message>
    <message>
        <source>Icons Theme</source>
        <translation>Ikontema</translation>
    </message>
    <message>
        <source>Razor Theme</source>
        <translation>Razor Tema</translation>
    </message>
</context>
<context>
    <name>RazorThemeConfig</name>
    <message>
        <source>Razor Theme</source>
        <translation>Razor Tema</translation>
    </message>
</context>
</TS>